/* GRJ, Apr/May 2020
 */


package beast.evolution.tree;

import beast.core.Distribution;
import beast.core.Input;
import beast.core.State;

import java.util.List;


import java.util.Random;

import static beast.evolution.pomocov.TransmissionDistributions.*;

/*
calculates logPrior for transmission tree
 */

public class TreePoMoCoVPrior  extends Distribution {

    final public Input<TreePoMo> treeInput = new Input<>("tree",
            "phylogenetic transmission PoMo tree with sequence data in the leafs and internal nodes",
            Input.Validate.REQUIRED);




    @Override
    public List<String> getArguments() {
        return null;
    }

    @Override
    public List<String> getConditions() {
        return null;
    }

    @Override
    public void sample(State state, Random random) {

    }


    @Override
    public double calculateLogP() {
        logP = 0.0;
        if (treeInput.get().getUnobservedCases()) {
            logP = calculateTreeLogPrior(treeInput.get());
        }
        return logP;
    }



    private double calculateTreeLogPrior(TreePoMo tree) {
        double logPrior = 0.0;
        NodePoMo[] nodes = tree.getNodesAsArray();
        for (NodePoMo node : nodes) {
            double h = node.getHeight();
            if (node.getParent() != null) {
                double g = node.getOriginHeight();
                int u = node.getUnobservedCount();
                logPrior += betweenHostsLogPrior(u, g, h);
                logPrior += unobservedCountLogPrior(u);
            }
            for (NodePoMo ch : node.getChildren()) {
                logPrior += withinHostLogPrior(h - ch.getHeight());
            }
        }
        return logPrior;
    }






}
